@@ -3,7 +3,7 @@
 # Apache::Session::Store::File
 # Implements session object storage via flat files
 # Copyright(c) 1998, 1999, 2000, 2004 Jeffrey William Baker (jwbaker@acm.org)
-# Distribute under the Artistic License
+# Distribute under the Perl License
 #
 ############################################################################
 
@@ -14,7 +14,7 @@ use Symbol;
 use Fcntl;
 use vars qw($VERSION);
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 $Apache::Session::Store::File::Directory = '/tmp';
 
@@ -38,8 +38,9 @@ sub insert {
         die "Object already exists in the data store";
     }
     
-    sysopen ($self->{fh}, $directory.'/'.$session->{data}->{_session_id}, O_RDWR|O_CREAT) ||
-        die "Could not open file ".$directory.'/'.$session->{data}->{_session_id}.": $!";
+    my $file = $directory.'/'.$session->{data}->{_session_id};
+    sysopen ($self->{fh}, $file, O_RDWR|O_CREAT) ||
+        die "Could not open file $file: $!";
 
     $self->{opened} = 1;
     
@@ -53,9 +54,10 @@ sub update {
     my $directory = $session->{args}->{Directory} || $Apache::Session::Store::File::Directory;
 
     if (!$self->{opened}) {
-        sysopen ($self->{fh}, $directory.'/'.$session->{data}->{_session_id}, O_RDWR|O_CREAT) ||
-            die "Could not open file: $!";
-        
+        my $file = $directory.'/'.$session->{data}->{_session_id};
+        sysopen ($self->{fh}, $file, O_RDWR|O_CREAT) ||
+            die "Could not open file $file: $!";
+
         $self->{opened} = 1;
     }
     
@@ -70,10 +72,11 @@ sub materialize {
     
     my $directory = $session->{args}->{Directory} || $Apache::Session::Store::File::Directory;
     
-    if (-e $directory.'/'.$session->{data}->{_session_id}) {
+    my $file = $directory.'/'.$session->{data}->{_session_id};
+    if (-e $file) {
         if (!$self->{opened}) {
-            sysopen ($self->{fh}, $directory.'/'.$session->{data}->{_session_id}, O_RDWR|O_CREAT) ||
-                die "Could not open file: $!";
+            sysopen ($self->{fh}, $file, O_RDWR|O_CREAT) ||
+                die "Could not open file $file: $!";
 
             $self->{opened} = 1;
         }
@@ -102,9 +105,10 @@ sub remove {
         $self->{opened} = 0;
     }
 
-    if (-e $directory.'/'.$session->{data}->{_session_id}) {
-        unlink ($directory.'/'.$session->{data}->{_session_id}) ||
-            die "Could not remove file: $!";
+    my $file = $directory.'/'.$session->{data}->{_session_id};
+    if (-e $file) {
+        unlink ($file) ||
+            die "Could not remove file $file: $!";
     }
     else {
         die "Object does not exist in the data store";
@@ -140,9 +144,9 @@ Apache::Session::Store::File - Store persistent data on the filesystem
 
 
  use Apache::Session::Store::File;
- 
+
  my $store = new Apache::Session::Store::File;
- 
+
  $store->insert($ref);
  $store->update($ref);
  $store->materialize($ref);
